# manowar_agent

Agent for Manowar. Designed to be an agent that you can stick on a box and 
get a moderately complete picture of what is on the device.

* [![Snap Status](https://build.snapcraft.io/badge/chalbersma/manowar_agent.svg)](https://build.snapcraft.io/user/chalbersma/manowar_agent)
